<template>
  <el-bus-crud ref="crud" v-bind="tableConfig"></el-bus-crud>
</template>

<script>
export default {
  data() {
    return {
      tableConfig: {
        url: 'flower/api/sales/list',
        hasNew: false,
        hasEdit: false,
        hasDelete: false,
        onResetView: (row) => {
          this.$router.push(`${this.$route.path}/view/${row.id}`)
        },
        operationAttrs: {
          width: 120,
          fixed: 'right',
        },
        extraButtons: [
          {
            text: '售后处理',
            show: (row) => row.status === 'PENDING',
            atClick: (row) => {
              this.$router.push(`${this.$route.path}/handle/${row.id}`)
            },
          },
        ],
        columns: [
          { label: '订单号', prop: 'orderNo', minWidth: 150, fixed: 'left' },
          { label: '售后单号', prop: 'salesNo', minWidth: 150 },
          { label: '收货人', prop: 'customer', minWidth: 120 },
          { label: '收货人电话', prop: 'customerTel', minWidth: 120 },
          {
            label: '收货地址',
            formatter: (row) =>
              `${row.customerProvince || ''}${row.customerCity || ''}${
                row.customerRegion || ''
              }${row.customerAddress || ''}`,
            minWidth: 250,
          },
          { label: '订单金额', prop: 'totalOrderAmount', minWidth: 150 },
          { label: '售后理由', prop: 'reason', minWidth: 200 },
          { label: '售后状态', prop: 'statusStr', minWidth: 120 },
          { label: '审核状态', prop: 'auditStatusStr', minWidth: 120 },
          { label: '申请时间', prop: 'createTime', minWidth: 180 },
          { label: '处理时间', prop: 'auditTime', minWidth: 180 },
        ],
        searchFormAttrs: {
          labelWidth: 'auto',
        },
        searchForm: [
          {
            type: 'row',
            items: [
              {
                label: '售后状态：',
                id: 'status',
                type: 'bus-radio',
                el: {
                  hasAll: true,
                  childType: 'el-radio-button',
                  code: 'SALES_STATUS',
                },
                default: '',
                span: 24,
                searchImmediately: true,
              },
              {
                label: '审核状态：',
                id: 'auditStatus',
                type: 'bus-radio',
                el: {
                  hasAll: true,
                  childType: 'el-radio-button',
                  code: 'SALES_AUDIT_STATUS',
                },
                default: '',
                span: 24,
                searchImmediately: true,
              },
              { label: '订单号：', id: 'orderNo', type: 'input' },
              { label: '售后单号：', id: 'salesNo', type: 'input' },
            ],
          },
        ],
      },
    }
  },
  head() {
    return {
      title: '售后理赔',
    }
  },
}
</script>

<style lang="scss" scoped></style>
